@@ -1,6 +1,6 @@
 from snakypy.helpers import printer
 from snakypy.helpers.ansi import FG
-from snakypy.helpers.catches.generic import whoami
+from snakypy.helpers.checking import whoami
 
 from snakypy.zshpower.config.base import Base
 from snakypy.zshpower.utils.catch import get_zsh_theme
@@ -10,7 +10,7 @@ from snakypy.zshpower.utils.process import reload_zsh
 
 
 class ActivateCommand(Base):
-    def __init__(self, home):
+    def __init__(self, home: str):
         Base.__init__(self, home)
 
     def run(self) -> bool:
